@@ -53,6 +53,12 @@ def test_dea_style_package(
 
         # Write a thumbnail using the given bands as r/g/b.
         p.write_thumbnail("ones", "ones", "blue")
+        # Write a singleband thumbnail using a bit flag
+        p.write_thumbnail_singleband("blue", bit=1, kind="singleband")
+        # Write a singleband thumbnail using a lookuptable
+        p.write_thumbnail_singleband(
+            "blue", lookup_table={1: [0, 0, 255]}, kind="singleband_lut"
+        )
 
         # Note any software versions important to this created data.
         p.note_software_version(
@@ -402,6 +408,33 @@ def test_complain_about_missing_fields(tmp_path: Path, l1_ls8_folder: Path):
             )
 
 
+def test_dea_interim_folder_calculation(tmp_path: Path):
+    """
+    DEA Naming conventions should include maturity in the folder name
+    when it's not a 'final' dataset.
+    """
+    with DatasetAssembler(tmp_path, naming_conventions="dea") as p:
+        p.platform = "landsat-7"
+        p.instrument = "ETM+"
+        p.datetime = datetime(1998, 7, 30)
+        p.product_family = "frogs"
+        p.processed = "1999-11-20 00:00:53.152462Z"
+        p.maturity = "interim"
+        p.producer = "ga.gov.au"
+        p.properties["landsat:landsat_scene_id"] = "LE70930821999324EDC00"
+        p.dataset_version = "1.2.3"
+        p.region_code = "093082"
+
+        p.done()
+
+    [metadata_path] = tmp_path.rglob("*.odc-metadata.yaml")
+    calculated_path: Path = metadata_path.relative_to(tmp_path)
+    assert calculated_path == Path(
+        #                                  ⇩⇩⇩⇩⇩⇩⇩⇩ Adds interim flag
+        "ga_ls7e_frogs_1/093/082/1998/07/30_interim/ga_ls7e_frogs_1-2-3_093082_1998-07-30_interim.odc-metadata.yaml"
+    )
+
+
 def test_dea_c3_naming_conventions(tmp_path: Path):
     """
     A sample scene for Alchemist C3 processing that tests the naming conventions.
@@ -435,3 +468,43 @@ def test_dea_c3_naming_conventions(tmp_path: Path):
         metadata_path_offset
         == "ga_ls_wo_3/1-6-0/090/081/1998/07/30/ga_ls_wo_3_090081_1998-07-30_interim.odc-metadata.yaml"
     )
+
+
+@pytest.mark.parametrize(
+    "inherit_geom",
+    [True, False],
+    ids=["inherit geom from dataset", "don't inherit geom"],
+)
+def test_add_source_dataset(tmp_path: Path, inherit_geom):
+    from eodatasets3 import serialise
+
+    p = DatasetAssembler(tmp_path, naming_conventions="dea_c3")
+    source_dataset = serialise.from_path(
+        Path(__file__).parent / "data/LC08_L1TP_089080_20160302_20170328_01_T1.yaml"
+    )
+    p.add_source_dataset(
+        source_dataset, auto_inherit_properties=True, inherit_geometry=inherit_geom
+    )
+
+    p.maturity = "interim"
+    p.collection_number = "3"
+    p.dataset_version = "1.6.0"
+    p.producer = "ga.gov.au"
+    p.processed = "1998-07-30T12:23:23"
+    p.product_family = "wofs"
+    p.write_measurement(
+        "water",
+        Path(__file__).parent
+        / "data/wofs/ga_ls_wofs_3_099081_2020-07-26_interim_water_clipped.tif",
+    )
+
+    id, path = p.done()
+
+    output = serialise.from_path(path)
+    if inherit_geom:
+        # POLYGON((609615 - 3077085, 378285 - 3077085, 378285 - 3310515, 609615 - 3310515, 609615 - 3077085))
+        assert output.geometry == source_dataset.geometry
+    else:
+        # POLYGON((684285 - 3439275, 684285 - 3444495, 689925 - 3444495, 689925 - 3439275, 684285 - 3439275))
+        # Geometry is not set from the source dataset, but instead from the added wofs measurement
+        assert output.geometry != source_dataset.geometry
